@@ -3,7 +3,7 @@
  * c_defs.h - C macro defines to ease ratfor to C conversion.  Included
  *               in all files.
  *
- * $Id: c_defs.h 552 2006-07-17 04:47:23Z jon $
+ * $Id: c_defs.h 694 2007-03-12 01:59:32Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ************************************************************************/
@@ -31,13 +31,13 @@
 #endif
 
 #if defined(HAVE_UNISTD_H)
-# if defined(LINUX)
-#  define _XOPEN_SOURCE
-#  define __USE_XOPEN		/* Why? */
-# endif
 # include <unistd.h>
 #endif 
 
+#if defined(HAVE_CRYPT_H)
+# include <crypt.h>
+#endif 
+
 #if defined(STDC_HEADERS)
 # include <stdlib.h>
 # include <stdio.h>
