@@ -4,7 +4,7 @@
  *
  * client specific stuff
  *
- * $Id: client.c 564 2006-07-24 00:52:28Z jon $
+ * $Id: client.c 708 2007-07-09 03:25:35Z jon $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -772,6 +772,22 @@ int clientHello(char *clientname)
     return FALSE;
   }
 
+  /* we only get this if there's problem (server denied access, usually) */
+  if (pkttype == SP_ACKMSG || pkttype == SP_ACK)
+    {
+      if (pkttype == SP_ACKMSG)
+        {
+          sackmsg = (spAckMsg_t *)buf;
+          if (sackmsg->txt)
+            {
+              clog("clientHello: %s '%s'",
+                   psev2String(sackmsg->severity),
+                   sackmsg->txt);
+            }
+        }
+      return FALSE;
+    }
+
   if (pkttype != SP_HELLO)
   {
     clog("clientHello: read server hello: wrong packet type %d\n", pkttype);
@@ -984,11 +1000,13 @@ void processPacket(Unsgn8 *buf)
       break;
 
     case SP_CLIENTSTAT:
-      scstat = (spClientStat_t *)buf;
-      Context.snum = scstat->snum;
-      Context.unum = (int)ntohs(scstat->unum);
-      Ships[Context.snum].team = scstat->team;
-      clientFlags = scstat->flags;
+      if ((scstat = chkClientStat(buf)))
+        {
+          Context.snum = scstat->snum;
+          Context.unum = scstat->unum;
+          Ships[Context.snum].team = scstat->team;
+          clientFlags = scstat->flags;
+        }
       break;
 
     case SP_MESSAGE:
@@ -1066,3 +1084,45 @@ void sendUDPKeepAlive(Unsgn32 timebase)
 
   return;
 }
+
+/* this function accepts a character buffer representing a clientstat packet
+   and validates it.  It return a pointer to a static spClientStat_t
+   packet if everything is in order, NULL otherwise. */
+spClientStat_t *chkClientStat(char *buf)
+{
+  static spClientStat_t scstat;
+
+  if (!buf)
+    return NULL;
+
+  scstat = *(spClientStat_t *)buf;
+  
+  scstat.unum = (Unsgn16)ntohs(scstat.unum);
+
+  if (scstat.unum >= MAXUSERS)
+    {
+#if defined(DEBUG_PKT)
+      clog("%s: unum not in valid range", __FUNCTION__);
+#endif
+      return NULL;
+    }
+
+  if (scstat.snum < 1 || scstat.snum > MAXSHIPS)
+    {
+#if defined(DEBUG_PKT)
+      clog("%s: snum not in valid range", __FUNCTION__);
+#endif
+      return NULL;
+    }
+
+  if (scstat.team >= NUMALLTEAMS)
+    {
+#if defined(DEBUG_PKT)
+      clog("%s: team not in valid range", __FUNCTION__);
+#endif
+      return NULL;
+    }
+
+  return &scstat;
+}
+  
