@@ -4,7 +4,7 @@
  *
  * conf.c - handle configuration issues, both personal and system wide.
  *
- * $Id: conf.c 636 2006-09-02 00:23:06Z jon $
+ * $Id: conf.c 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -103,6 +103,9 @@ void setUserConfDefaults(void)
   UserConf.DoTacBkg = FALSE;
   UserConf.DoTacShade = 50;
 
+  UserConf.musicVol = 100;
+  UserConf.effectsVol = 100;
+
   for (i=0; i<MAX_MACROS; i++)
     UserConf.MacrosF[i][0] = EOS;
 
@@ -130,7 +133,7 @@ void setUserConfDefaults(void)
 }
 
 /* here we look for a ~/.conquest/ directory, and try to create it if it
-   does nt exist */
+   doesn't exist */
 static void checkCreateUserConfDir(void)
 {
   char buffer[BUFFER_SIZE];
