@@ -2,7 +2,7 @@
  *
  * conf.h - header for conf.c
  *
- * $Id: conf.h 636 2006-09-02 00:23:06Z jon $
+ * $Id: conf.h 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -126,6 +126,9 @@ typedef struct _userConf {
 
   int DoTacShade;               /* tactical background alpha */
 
+  int musicVol;                 /* nusic/effects volume */
+  int effectsVol;
+
   char MacrosF[MAX_MACROS][MAX_MACRO_LEN];
 
   /* mouse macros, indexed by [max buttons][modifiers (8)]  */
@@ -173,7 +176,7 @@ typedef struct _sysConf {
 CEXTERN char ConfigVersion[];
 
 #else
-char ConfigVersion[] = "$Revision: 636 $";
+char ConfigVersion[] = "$Revision: 688 $";
 #endif /* CONF_NOEXTERN */
 
 /* Config's */
@@ -735,6 +738,34 @@ struct Conf ConfData[] =
       NULL
     }
   },
+  {
+    FALSE,
+    CTYPE_NUMERIC,
+    "music_vol=",
+    &UserConf.musicVol,
+    0, 100,                      /* min/max */
+    "Music Volume (0-100) 0 = off",
+    {
+      "# Set the music volume.  If set to 0, then music is turned",
+      "#  off.  valid values 0 - 100",
+      "#  Default: 100",
+      NULL
+    }
+  },
+  {
+    FALSE,
+    CTYPE_NUMERIC,
+    "effects_vol=",
+    &UserConf.effectsVol,
+    0, 100,                      /* min/max */
+    "Effects Volume (0-100) 0 = off",
+    {
+      "# Set the effects volume.  If set to 0, then effects are turned",
+      "#  off.  valid values 0 - 100",
+      "#  Default: 100",
+      NULL
+    }
+  },
   {				/* mouse macros */
     FALSE,
     CTYPE_MOUSE,
