@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conqai.c,v 1.17 2004/05/08 21:01:41 jon Exp $
+ * $Id: conqai.c 576 2006-08-20 05:51:33Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -549,6 +549,9 @@ int newrob( int *snum, int unum )
   Ships[*snum].sdfuse = 0;
   Ships[*snum].pid = 0;
 
+  /* randomize it's desired heading */
+  Ships[*snum].dhead = rnduni(0.0, 359.9);
+
 				/* robots now can use 30/70
 				   instead of the default 40/60 set in
 				   clbInitShip(). */
