@@ -1,7 +1,7 @@
 
 /************************************************************************
  *
- * $Id: conqdef.h 568 2006-08-05 20:10:21Z jon $
+ * $Id: conqdef.h 694 2007-03-12 01:59:32Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -75,7 +75,9 @@
 
 #define MAXSHIPS 20 		/* number of available ships */
 
-  /* Values for sstatus() */
+#define SHIPSIZE 225            /* base size of a ship in CU's */
+#define DOOMSIZE 900            /* base size of doomsday in CU's */
+/* Values for sstatus() */
 #define SS_OFF 1 		/* available for use */
 #define SS_ENTERING 2 		/* outfitting the ship in newship() */
 #define SS_LIVE 3 		/* flying around */
@@ -594,9 +596,6 @@
 #define UT_LOCAL (0)
 #define UT_REMOTE (1)
 
-#define TEXFILEMAX 64           /* maximum lenth of a texture filename (no
-                                   path) */
-
 /* Macros, here order is important. */
 
 #define my_rint(x) ((real)floor((x) + 0.5)) /* standard round. */
