@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conqlb.c 628 2006-08-27 07:48:19Z jon $
+ * $Id: conqlb.c 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -446,7 +446,10 @@ void clbKillShip( int snum, int kb )
 /* does NO LOCKING, so only use from the client */
 int clbCheckLaunch(int snum, int number)
 {
-  register int i;
+  int i;
+
+  if (Ships[snum].wfuse > 0)
+    return FALSE;               /* weapons overloaded */
 
   if (number == 0)
     return TRUE;
