@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conqsvr42.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: conqsvr42.c 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -353,6 +353,16 @@ void drstart(void)
 void gcputime( int *cpu )
 {
   static struct tms Ptimes;
+#ifndef CLK_TCK
+# ifdef LINUX
+   extern long int __sysconf (int);
+#  define CLK_TCK ((__clock_t) __sysconf (_SC_CLK_TCK))
+# else
+#  define CLK_TCK CLOCKS_PER_SEC
+# endif
+#endif
+
+   /* JET - I think this function has outlived it's usefulness. */
   
   times(&Ptimes);
   
