@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conquest.c 636 2006-09-02 00:23:06Z jon $
+ * $Id: conquest.c 698 2007-05-14 02:24:01Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -131,6 +131,7 @@ void printUsage()
   printf("    -B              Benchmark mode.  When playing back a recording,\n");
   printf("                    the default playback speed will be as fast as possible.\n");
   printf("    -u              do not attempt to use UDP from server.\n");
+  printf("    -v              be more verbose.\n");
   return;
 }
 
@@ -271,7 +272,7 @@ int main(int argc, char *argv[])
   cInfo.remotehost = strdup("localhost"); /* default to your own server */
 
   /* check options */
-  while ((i = getopt(argc, argv, "mM:s:r:tP:Bu")) != EOF)    /* get command args */
+  while ((i = getopt(argc, argv, "mM:s:r:tP:Buv")) != EOF)    /* get command args */
     switch (i)
       {
       case 'B':                 /* Benchmark mode, set frameDelay to 0.0 */
@@ -339,6 +340,10 @@ int main(int argc, char *argv[])
         cInfo.tryUDP = FALSE;
         break;
 
+      case 'v':
+        cqDebug++;
+        break;
+
       default:
 	printUsage();
 	exit(1);
@@ -3132,7 +3137,7 @@ int newship( int unum, int *snum )
 	      break;
 	      
 	    default:
-	      clog("conquest:newship: unexpected ack code %d",
+	      clog("newship: unexpected ack code %d",
 		   sack->code);
 	      break;
 	    }
@@ -3141,21 +3146,27 @@ int newship( int unum, int *snum )
 	  break;
 	  
 	case SP_CLIENTSTAT:
-	  scstat = (spClientStat_t *)buf;
-	  
-	  /* first things first */
-	  Context.unum = (int)ntohs(scstat->unum);
-	  Context.snum = scstat->snum;
-	  Ships[Context.snum].team = scstat->team;
-	  
-	  if (scstat->esystem == 0)	/* we are done */
-	    return TRUE;
-	  
-	  /* otherwise, need to prompt for system to enter */
-	  if (selectentry(scstat->esystem))
-	    return TRUE;		/* done */
-	  else
-	    return FALSE;
+          if ((scstat = chkClientStat(buf)))  
+            {
+              /* first things first */
+              Context.unum = scstat->unum;
+              Context.snum = scstat->snum;
+              Ships[Context.snum].team = scstat->team;
+              
+              if (scstat->esystem == 0)	/* we are done */
+                return TRUE;
+              
+              /* otherwise, need to prompt for system to enter */
+              if (selectentry(scstat->esystem))
+                return TRUE;		/* done */
+              else
+                return FALSE;
+            }
+          else
+            {
+              clog("newship: invalid CLIENTSTAT\n");
+              return FALSE;       /* don't want to hang if a bad pkt */
+            }
 	  
 	  break;
 	  
@@ -3322,7 +3333,7 @@ int welcome( int *unum )
   char * selected_str="You have been selected to command a";
   char * starship_str=" starship.";
   char * prepare_str="Prepare to be beamed aboard...";
-  spClientStat_t scstat = {};
+  spClientStat_t *scstat = NULL;
   spAck_t *sack = NULL;
   int pkttype;
   Unsgn8 buf[PKT_MAXSIZE];
@@ -3350,12 +3361,18 @@ int welcome( int *unum )
       switch (pkttype)
         {
         case SP_CLIENTSTAT:
-          scstat = *(spClientStat_t *)buf;
-          
-          *unum = (int)ntohs(scstat.unum);
-          Context.snum = scstat.snum;
-          Ships[Context.snum].team = scstat.team;
-          done = TRUE;
+          if ((scstat = chkClientStat(buf)))
+            {
+              *unum = scstat->unum;
+              Context.snum = scstat->snum;
+              Ships[Context.snum].team = scstat->team;
+              done = TRUE;
+            }
+          else
+            {
+              clog("welcome: invalid CLIENTSTAT\n");
+              return FALSE;
+            }
 
           break;
         case SP_ACK:
@@ -3370,7 +3387,7 @@ int welcome( int *unum )
         }
     }
 
-  if ( pkttype == SP_CLIENTSTAT && (scstat.flags & SPCLNTSTAT_FLAG_NEW) )
+  if ( pkttype == SP_CLIENTSTAT && (scstat->flags & SPCLNTSTAT_FLAG_NEW) )
     {				
       /* Must be a new player. */
       cdclear();
@@ -3385,7 +3402,7 @@ int welcome( int *unum )
 	  c_sleep( 2.0 );
 	  return ( FALSE );
 	}
-      team = scstat.team;
+      team = scstat->team;
       cbuf[0] = EOS;
       apptitle( team, cbuf );
       appchr( ' ', cbuf );
