@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: gldisplay.c 633 2006-09-01 22:02:29Z jon $
+ * $Id: gldisplay.c 705 2007-06-30 22:43:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -28,6 +28,9 @@
 
 #include "node.h"
 
+#include "cqsound.h"
+
+
 #include <GL/gl.h>
 #include <GL/glu.h>
 #include <GL/glx.h>
@@ -98,8 +101,12 @@ void display( int snum, int display_info )
   static int WeapAttrib = 0;
   static int EngAttrib = 0;
   static int DamageAttrib = 0;
+  static int talertfx = -1;
   int color;
   GLfloat glx, gly;
+  
+  if (talertfx == -1)
+      talertfx = cqsFindEffect("torp-alert");
 
   setXtraInfo();
   setAlertBorder(alertcolor(AlertLevel));
@@ -150,7 +157,7 @@ void display( int snum, int display_info )
     {
       if ( ! Planets[i].real )
 	continue; /*next;*/
-      if ( !GLcvtcoords( cenx, ceny, Planets[i].x, Planets[i].y, scale, 
+      if ( !GLcvtcoords( cenx, ceny, Planets[i].x, Planets[i].y, -scale, 
                          &glx, &gly ))
 	continue; /* next;*/
 
@@ -199,7 +206,7 @@ void display( int snum, int display_info )
   /* Display the planet eater. */
   if ( Doomsday->status == DS_LIVE )
     {
-      if (GLcvtcoords( cenx, ceny, Doomsday->x, Doomsday->y, scale, 
+      if (GLcvtcoords( cenx, ceny, Doomsday->x, Doomsday->y, -scale, 
 		       &glx, &gly ))
 	{
 	  drawDoomsday(glx, gly, (GLfloat)Doomsday->heading, scale);
@@ -232,7 +239,7 @@ void display( int snum, int display_info )
 		      if ( Ships[i].torps[j].status == TS_LIVE 
 			  || Ships[i].torps[j].status == TS_DETONATE )
 			if ( GLcvtcoords( cenx, ceny, Ships[i].torps[j].x, 
-					 Ships[i].torps[j].y, scale, 
+					 Ships[i].torps[j].y, -scale, 
 					 &glx, &gly ) )
 			  {
 			    drawTorp(glx, gly, Teams[Ships[i].team].torpchar, 
@@ -293,17 +300,18 @@ void display( int snum, int display_info )
 		/* ... especially if he's in the bounds of our current */
 		/*  display (either tactical or strategic map) */
 		if (GLcvtcoords( cenx, ceny, Ships[i].x, Ships[i].y, 
-				 scale, &glx, &gly ))
+				 -scale, &glx, &gly ))
 		  {
 		    /* He's on the screen. */
 		    /* We can see him if one of the following is true: */
 
-		    /*  - We are not looking at our strategic map */
+		    /*  - We are not looking at our strategic map and
+                          the ship is within scanning distance */
 		    /*  - We're mutually at peace */
 		    /*  - Our team has scanned him and we're not self-war */
 		    /*  - He's within accurate scanning range */
 		    
-		    if ( ( ! lsmap ) ||
+		    if ( ( ! lsmap && SSCANDIST(i)) ||
 			( snum > 0 && !satwar(i, snum) ) ||
 			( snum > 0 && Ships[i].scanned[Ships[snum].team] && 
 			  !selfwar(snum) ) ||
@@ -343,19 +351,22 @@ void display( int snum, int display_info )
      blending of explosions works on the ships. */
   for ( i = 1; i <= MAXSHIPS; i = i + 1 )
     {
-      if ( ! lsmap )
+      /* explosions first */
+      if ( snum < 0 || (snum > 0 && UserConf.DoExplode) ) /* dwp */
+        for ( j = 0; j < MAXTORPS; j = j + 1 )
+          if ( Ships[i].torps[j].status == TS_FIREBALL )
+            {
+              /* First display exploding torps. */
+              if ( GLcvtcoords( cenx, ceny, Ships[i].torps[j].x, 
+                                Ships[i].torps[j].y, -scale, &glx, &gly ))
+                { 
+                  drawExplosion(glx, gly, i, j, scale);
+                }
+            }
+
+      if ( ! lsmap ) 
 	{
-	  /* First display exploding torps. */
-	  if ( snum < 0 || (snum > 0 && UserConf.DoExplode) ) /* dwp */
-	    for ( j = 0; j < MAXTORPS; j = j + 1 )
-	      if ( Ships[i].torps[j].status == TS_FIREBALL )
-		if ( GLcvtcoords( cenx, ceny, Ships[i].torps[j].x, 
-                                  Ships[i].torps[j].y, scale, &glx, &gly ))
-		  { 
-		    drawExplosion(glx, gly, i, j);
-		  }
 	  /* Now display the live torps. */
-	  
 	  if (snum > 0)
 	    {			/* a ship */
 
@@ -375,7 +386,7 @@ void display( int snum, int display_info )
 	    if ( Ships[i].status != SS_DYING && Ships[i].status != SS_DEAD && 
 		 (Ships[i].torps[j].status == TS_LIVE || Ships[i].torps[j].status == TS_DETONATE) )
 	      if (GLcvtcoords( cenx, ceny, Ships[i].torps[j].x, 
-                               Ships[i].torps[j].y, scale, &glx, &gly))
+                               Ships[i].torps[j].y, -scale, &glx, &gly))
 		{
 		  drawTorp(glx, gly, Teams[Ships[i].team].torpchar, color,
                            scale, i, j);
@@ -414,6 +425,8 @@ void display( int snum, int display_info )
 	      AlertLevel = YELLOW_ALERT;
 	      c_strcpy( "Torp Alert", buf );
 	      minenemy = 0;			/* disable nearby enemy code */
+              cqsEffectPlay(talertfx, 0, 0, 0);
+
 	      dobeep = TRUE;
 	    }
 	  else if ( mindis < YELLOW_DIST )
@@ -504,16 +517,7 @@ void display( int snum, int display_info )
     x = Ships[snum].warp;
     if ( x != zzswarp )
       {
-	if ( x >= 0.0 )
-	  {
-	    sprintf( buf, "%2.1f", x );
-	    setWarp(buf);
-	  }
-	else
-	  {
-	    setWarp("Orbit");
-	  }
-	
+        setWarp(x);
 	zzswarp = x;
       }
     
@@ -609,7 +613,12 @@ void display( int snum, int display_info )
     
     /* Damage/repair. */
     if ( Ships[snum].damage > prevdam )
-      dobeep = TRUE;
+      {
+        if ( (Ships[snum].damage - prevdam) > 5 )
+          cqsEffectPlay(teamEffects[Ships[snum].team].hit, 0, 0, 0);
+
+        dobeep = TRUE;
+      }
     prevdam = Ships[snum].damage;
     
     i = round( Ships[snum].damage );
@@ -719,7 +728,7 @@ void display( int snum, int display_info )
   
     if ( dobeep )
       if ( UserConf.DoAlarms )
-	mglBeep();
+	mglBeep(MGL_BEEP_ALERT);
   
   } /* end of ship stats display */
   
@@ -736,3 +745,4 @@ void displayFeedback(char *msg, int lin)
 
   return;
 }
+
