@@ -2,7 +2,7 @@
  *
  * Jon Trulson, 2/2004
  *
- * $Id: glfont.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: glfont.c 694 2007-03-12 01:59:32Z jon $
  *
  * Copyright 2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -121,7 +121,8 @@ void glfRender(GLfloat x, GLfloat y, GLfloat z, GLfloat w, GLfloat h,
     xs = w/(GLfloat)width;
 
   ys = ((2.0 * (h/(ascent + descent))) * 0.70);
-      
+
+
 #if 0
   clog("glfRender(%s): WINDOW: %d, w = %f h = %f, \n"
        "\twid = %d, asc = %d desc = %d"
@@ -136,7 +137,6 @@ void glfRender(GLfloat x, GLfloat y, GLfloat z, GLfloat w, GLfloat h,
                   GL_LINEAR_MIPMAP_LINEAR);
 
   glPushMatrix();
-  glLoadIdentity();
 
   if (ortho) 
     {
@@ -146,7 +146,7 @@ void glfRender(GLfloat x, GLfloat y, GLfloat z, GLfloat w, GLfloat h,
   else
     {
       glTranslatef( x, y - h, z );
-      glScalef(xs, inverty * ys, 1.0);
+      glScalef(xs, inverty * ys, 1.0); 
     }
 
   if (glcol)
