@@ -1,7 +1,7 @@
 /* 
  *  gl font handling
  *
- * $Id: glfont.h,v 1.5 2004/10/25 00:15:34 jon Exp $
+ * $Id: glfont.h 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -28,8 +28,8 @@ extern TexFont *fontMsgTxf;
 #endif /* NOEXTERN_GLFONT */
 
 void glfRender(GLfloat x, GLfloat y, GLfloat z, GLfloat w, GLfloat h,
-                       TexFont *font, char *str, int color, int scalex,
-               int dofancy, int ortho);
+               TexFont *font, char *str, int color, GLColor_t *col,
+               int scalex, int dofancy, int ortho);
 void initTexFonts(void);
 
 
