@@ -1,7 +1,7 @@
 /* 
  * misc gl funcs
  *
- * $Id: glmisc.h 552 2006-07-17 04:47:23Z jon $
+ * $Id: glmisc.h 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -12,12 +12,18 @@
 #define VIEWANGLE 45.0
 #define TRANZ     -100.0
 
+
+#define MGL_BEEP_ALERT    0
+#define MGL_BEEP_MSG      1
+#define MGL_BEEP_ERR      2
+
+
 int _GLError(const char *funcname, const char *filename, int line);
 
 #define GLError() _GLError(__FUNCTION__, __FILE__, __LINE__)
 
 void mglConqLogo(dspConfig_t *dsp, bool mult);
-void mglBeep(void);  
+void mglBeep(int type);  
 void mglOverlayQuad(void);
 
 #endif /* _MISCGL_H */
