@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * $Id: global.h 552 2006-07-17 04:47:23Z jon $
+ * $Id: global.h 698 2007-05-14 02:24:01Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -29,12 +29,18 @@ CEXTERN	   int PollInputfd;	/* a copy of stdin's fd for poll()/select() */
 CEXTERN    int ConquestGID;	/* Conquest's GID */
 CEXTERN    int RMsg_Line;
 
-				/* for the semaphores */
-
+/* for the semaphores */
 #define LOCKMSG      (0)	/* lock the message portion  */
 #define LOCKCMN      (1)	/* lock everything else  */
 
 CEXTERN int headerflag;         /* whether to show header flag */
 
+/* verbosity/debugging */
+#if defined(NOEXTERNGLOBALS)
+int cqDebug = 0;
+#else
+CEXTERN int cqDebug;
+#endif
+
 #undef CEXTERN			/* cleanup */
 #endif
