@@ -5,7 +5,7 @@
  * ibuf.c - input buffering to support Function key macros
  * Jon Trulson 3/30/96
  *
- * $Id: ibuf.c,v 1.9 2005/05/30 08:22:47 jon Exp $
+ * $Id: ibuf.c 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  **********************************************************************/
@@ -40,10 +40,6 @@ void iBufInit(void)
 }
 
 
-/* iBufEmpty - return TRUE or FALSE depending on whether the buffer is 
- * empty 
- */
-
 int iBufCount(void)
 {
   return ndata;
@@ -175,3 +171,51 @@ int DoMacro(int fkey)
 
 }
       
+int DoMouseMacro(int but, Unsgn32 mods, real mangle)
+{
+  int myangle = ((mangle < 0.0) ? 0 : (int)mod360(mangle));
+  char *s;
+  static char buf[MAX_MACRO_LEN];
+
+  
+  if (but < 0 || but >= CONF_MAXBUTTONS)
+    return(FALSE);
+
+  if (mods < 0 || mods >= CONF_MAXMODIFIERS)
+    return(FALSE);
+
+  /* we need to translate any occurances of \a into the mangle (angle) */
+
+  s = UserConf.Mouse[but][mods];
+
+#if defined(DEBUG_MACROS)
+  clog("DoMouseMacro(): got MOUSE Macro Key: %d, mod %d string = '%s'", but,
+       mods, s);
+#endif
+
+  while (*s)
+    {
+      if (*s == '\\')
+        {
+          s++;
+
+          if (*s == 'a')
+            {
+              s++;
+              snprintf(buf, MAX_MACRO_LEN - 1, "%d",
+                       myangle);
+              iBufPut(buf); 
+            }
+          else
+            iBufPutc('\\');
+        }
+      else
+        {
+          iBufPutc((int)*s);
+          s++;
+        }
+    }
+
+  return(TRUE);
+}
+      
