@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * $Id: ibuf.h,v 1.6 2004/05/08 21:01:41 jon Exp $
+ * $Id: ibuf.h 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -16,6 +16,7 @@
 #ifndef IBUF_H
 #define IBUF_H
 
+#include "datatypes.h"
 #define    IBUFMAX 1024
 
 void iBufInit(void);
@@ -24,5 +25,6 @@ void iBufPut(char *thestr);
 void iBufPutc(unsigned int thechar);
 unsigned int iBufGetCh(void);
 int DoMacro(int fkey);
+int DoMouseMacro(int but, Unsgn32 mods, real mangle);
 
 #endif
