@@ -1,7 +1,7 @@
 /* 
  * cockpit node
  *
- * $Id: nCP.h 552 2006-07-17 04:47:23Z jon $
+ * $Id: nCP.h 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -9,6 +9,6 @@
 #ifndef _NCP_H
 #define _NCP_H
 
-void nCPInit(void);
+void nCPInit(int istopnode);
 
 #endif /* _NCP_H */
