@@ -1,7 +1,7 @@
 /* 
  * nCP help node
  *
- * $Id: nCPHelp.c 559 2006-07-20 00:41:42Z jon $
+ * $Id: nCPHelp.c 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -199,7 +199,7 @@ static int nCPHelpInput(int ch)
   /* go back */
 
   setONode(NULL);
-  nCPInit();
+  nCPInit(FALSE);
 
   return NODE_OK;
 }
