@@ -1,5 +1,5 @@
 /* 
- * $Id: nHistl.c 625 2006-08-26 22:24:57Z jon $
+ * $Id: nHistl.c 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -147,7 +147,7 @@ static int nHistlInput(int ch)
     {
     case DSP_NODE_CP:
       setONode(NULL);
-      nCPInit();
+      nCPInit(FALSE);
       break;
     case DSP_NODE_MENU:
       setONode(NULL);
