@@ -1,7 +1,7 @@
 /* 
  * menu node
  *
- * $Id: nMenu.c 688 2006-11-27 22:34:45Z jon $
+ * $Id: nMenu.c 706 2007-07-04 18:08:21Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -29,6 +29,7 @@
 #include "nTeaml.h"
 #include "nOptions.h"
 #include "cqkeys.h"
+#include "cqsound.h"
 
 extern void processPacket(Unsgn8 *buf);
 
@@ -524,7 +525,12 @@ static int nMenuInput(int ch)
       break;
      
     case 'q':
+      /* first stop all music and effects */
+      cqsEffectStop(CQS_INVHANDLE, TRUE);
+      cqsMusicStop(TRUE);
+      
       return NODE_EXIT;
+
       break;                    /* NOTREACHED */
 
     }
