@@ -1,7 +1,7 @@
 /* 
  * Planet listing
  *
- * $Id: nPlanetl.c 625 2006-08-26 22:24:57Z jon $
+ * $Id: nPlanetl.c 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -336,7 +336,7 @@ static int nPlanetlInput(int ch)
     {
     case DSP_NODE_CP:
       setONode(NULL);
-      nCPInit();
+      nCPInit(FALSE);
       break;
     case DSP_NODE_MENU:
       setONode(NULL);
