@@ -1,7 +1,7 @@
 /* 
  * playback cockpit node
  *
- * $Id: nPlayB.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: nPlayB.c 705 2007-06-30 22:43:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -46,6 +46,8 @@
 
 #include "nPlayB.h"
 
+#include "cqsound.h"
+
 #define cp_putmsg(str, lin)  setPrompt(lin, NULL, NoColor, str, NoColor)
 
 #define S_NONE         0
@@ -65,6 +67,9 @@ static char *nss = NULL;        /* no such ship */
 
 extern dspData_t dData;
 
+extern int ncpSRMagFactor;
+extern int ncpLRMagFactor;
+
 static int nPlayBDisplay(dspConfig_t *);
 static int nPlayBIdle(void);
 static int nPlayBInput(int ch);
@@ -194,9 +199,9 @@ void nPlayBInit(void)
       /* now setup the team torp animators */
       for (i=0; i<NUMPLAYERTEAMS; i++)
         {
-          char nm[TEXFILEMAX];
+          char nm[CQI_NAMELEN];
           
-          snprintf(nm, TEXFILEMAX - 1, "ship%c-torp", 
+          snprintf(nm, CQI_NAMELEN - 1, "ship%c-torp", 
                    Teams[i].name[0]);
           
           if (!animInitState(nm, &ncpTorpAnims[i], NULL))
@@ -454,7 +459,7 @@ static int nPlayBInput(int ch)
           Context.snum = snum;
         }
       else
-        mglBeep();
+        mglBeep(MGL_BEEP_ERR);
 
       break;
 
@@ -491,7 +496,7 @@ static int nPlayBInput(int ch)
               
               if (foundone == FALSE)
                 {
-                  mglBeep();
+                  mglBeep(MGL_BEEP_ERR);
                   break; /* didn't find one, beep, leave everything
                             alone*/
                 }
@@ -560,7 +565,7 @@ static int nPlayBInput(int ch)
               
               if (foundone == FALSE)
                 {
-                  mglBeep();
+                  mglBeep(MGL_BEEP_ERR);
                   break; /* didn't find one, beep, leave everything
                             alone*/
                 }
@@ -602,12 +607,83 @@ static int nPlayBInput(int ch)
         }
       
       break;
+
+    case '[':                   /* zoom out */
+      {
+        if (SMAP(snum))
+          {                     /* LR */
+            if (ncpLRMagFactor - 1 >= -5)
+              {
+                ncpLRMagFactor--;
+                cqsEffectPlay(teamEffects[Ships[snum].team].mag, 0, 0, 0);
+              }
+            else
+              mglBeep(MGL_BEEP_ERR);
+
+            setViewerScaling(ncpLRMagFactor, TRUE);
+          }
+        else
+          {
+            if (ncpSRMagFactor - 1 >= -5)
+              {
+                ncpSRMagFactor--;
+                cqsEffectPlay(teamEffects[Ships[snum].team].mag, 0, 0, 0);
+              }
+            else
+              mglBeep(MGL_BEEP_ERR);
+
+            setViewerScaling(ncpSRMagFactor, FALSE);
+          }
+      }
+      break;
+
+    case ']':                   /* zoom in */
+      {
+        if (SMAP(snum))
+          {                     /* LR */
+            if (ncpLRMagFactor + 1 <= 5)
+              {
+                ncpLRMagFactor++;
+                cqsEffectPlay(teamEffects[Ships[snum].team].mag, 0, 0, 0);
+              }
+            else
+              mglBeep(MGL_BEEP_ERR);
+
+            setViewerScaling(ncpLRMagFactor, TRUE);
+          }
+        else
+          {
+            if (ncpSRMagFactor + 1 <= 5)
+              {
+                ncpSRMagFactor++;
+                cqsEffectPlay(teamEffects[Ships[snum].team].mag, 0, 0, 0);
+              }
+            else
+              mglBeep(MGL_BEEP_ERR);
+
+            setViewerScaling(ncpSRMagFactor, FALSE);
+          }
+      }
+      break;
+
+    case TERM_REDRAW:			/* clear all the prompts */
+      clrPrompt(MSG_LIN1);
+      clrPrompt(MSG_LIN2);
+      clrPrompt(MSG_MSG);
+
+      /* reset the scaling factors */
+      ncpLRMagFactor = ncpSRMagFactor = 0;
+      setViewerScaling(ncpLRMagFactor, TRUE);
+      setViewerScaling(ncpSRMagFactor, FALSE);
+
+      break;
+
     case TERM_ABORT:
       nPlayBMenuInit();
       return NODE_OK;
       break;
     default:
-      mglBeep();
+      mglBeep(MGL_BEEP_ERR);
       cp_putmsg( "Type h for help.", MSG_LIN2 );
       break;
     }
