@@ -1,7 +1,7 @@
 /* 
  * Ship list
  *
- * $Id: nShipl.c 633 2006-09-01 22:02:29Z jon $
+ * $Id: nShipl.c 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -209,7 +209,7 @@ static int nShiplInput(int ch)
     {
     case DSP_NODE_CP:
       setONode(NULL);
-      nCPInit();
+      nCPInit(FALSE);
       break;
     case DSP_NODE_MENU:
       setONode(NULL);
