@@ -1,7 +1,7 @@
 /* 
  * nCP help node
  *
- * $Id: nTeaml.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: nTeaml.c 688 2006-11-27 22:34:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -332,7 +332,7 @@ static int nTeamlInput(int ch)
     {
     case DSP_NODE_CP:
       setONode(NULL);
-      nCPInit();
+      nCPInit(FALSE);
       break;
     case DSP_NODE_MENU:
       setONode(NULL);
