@@ -1,7 +1,7 @@
 /* 
  * Welcome to this node
  *
- * $Id: nWelcome.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: nWelcome.c 693 2007-03-04 02:15:46Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -104,12 +104,20 @@ void nWelcomeInit(void)
       switch (pkttype)
         {
         case SP_CLIENTSTAT:
-          scstat = (spClientStat_t *)buf;
-          
-          Context.unum = (int)ntohs(scstat->unum);
-          Context.snum = scstat->snum;
-          Ships[Context.snum].team = scstat->team;
-          done = TRUE;
+          if ((scstat = chkClientStat(buf)))
+            {
+              Context.unum = scstat->unum;
+              Context.snum = scstat->snum;
+              Ships[Context.snum].team = scstat->team;
+              done = TRUE;
+            }
+          else
+            {
+              clog("nWelcomeInit: invalid CLIENTSTAT");
+              fatal = TRUE;
+              done = TRUE;
+              return;
+            }
           break;
         case SP_ACK:
           sack = *(spAck_t *)buf;
