@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * $Id: node.h,v 1.4 2004/09/04 07:38:02 jon Exp $
+ * $Id: node.h 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -8,18 +8,25 @@
 #ifndef _NODE_H
 #define _NODE_H
 
+#include "cqmouse.h"
+
 /* node proc return values */
 #define NODE_OK        TRUE
 #define NODE_EXIT      FALSE
 #define NODE_ERR       ERR
+
 /* menu/screen node */
 
 
 typedef struct _scr_node {
   int (*display)(dspConfig_t *); /* display routine */
   int (*idle)(void);            /* idle routine */
-  int (*input)(int ch);         /* input routine */
-  struct _scr_node *next;       /* sub-nodes */
+  int (*input)(int ch);         /* keyboard input routine */
+  int (*minput)(mouseData_t *mdata); /* mouse input routine */
+  void *animQue;                /* optional aimation que.
+                                   we use void* for this since
+                                   we don't want to bring GL into
+                                   the picture here. */
 } scrNode_t;
 
 /* some nodes are called from other, multiple nodes, so we need
