@@ -1,7 +1,7 @@
 /* 
  * record.h - recording games in conquest
  *
- * $Id: record.h,v 1.6 2004/08/09 00:45:37 jon Exp $
+ * $Id: record.h 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -12,7 +12,8 @@
 #include "conqdef.h"
 #include "conqcom.h"
 
-#define RECVERSION 20031004 /* recording version */
+#define RECVERSION          20060409 /* current recording version */
+#define RECVERSION_20031004 20031004 /* older recording version(s) */
 
 				/* recording modes */
 #define RECMODE_OFF      0
@@ -28,19 +29,25 @@
                                        sizeof(Unsgn32) + \
                                        MAXUSERNAME + \
                                        sizeof(Unsgn32) + \
-                                       sizeof(Unsgn8)))
+                                       sizeof(Unsgn8) + \
+                                       sizeof(Unsgn32)))
 #pragma pack(1)
 typedef struct _fheader {	
-  Unsgn32 vers;		/* version of this file */
-  Unsgn8 samplerate;	/* recorded at samples per sec */
+  Unsgn32 vers;                 /* version of this file */
+  Unsgn8 samplerate;            /* recorded at samples per sec */
   Unsgn32 rectime;		/* time recorded */
   Unsgn8 user[MAXUSERNAME];	/* user that made recording */
   Unsgn32 cmnrev;               /* common block rev */
   Unsgn8 snum;                  /* ship that made rec.  0 == server record */
+  Unsgn32 flags;                /* flags. duh. */
   Unsgn8 pad[FHEADER_PAD];	/* padding */
 } fileHeader_t;
 #pragma pack()
 
+/* recording flags */
+#define RECORD_F_NONE           0x00000000
+#define RECORD_F_SERVER         0x00000001 /* server recording */
+
 /* playback */
 #ifdef REC_NOEXTERN
 time_t totElapsed = 0;          /* total game time (recorded) */
@@ -48,7 +55,7 @@ time_t startTime = 0;
 time_t currTime = 0;
 char *rfname = NULL;        /* name of recording file for playback */
 fileHeader_t fhdr;
-real framedelay = -1.0;         /* delaytime between frames */
+real frameDelay = -1.0;         /* delaytime between frames */
 Unsgn32 frameCount = 0;
 Msg_t recMsg = {};
 #else
@@ -57,7 +64,7 @@ extern time_t startTime;
 extern time_t currTime;
 extern char *rfname;        /* name of recording file for playback */
 extern fileHeader_t fhdr;
-extern real framedelay;         /* delaytime between frames */
+extern real frameDelay;         /* delaytime between frames */
 extern Unsgn32 frameCount;
 extern Msg_t recMsg;            /* current recMsg */
 #endif
@@ -69,7 +76,7 @@ void recordCloseInput(void);
 
 int recordOpenOutput(char *fname, int logit);
 void recordCloseOutput(void);
-int recordInitOutput(int unum, time_t thetime, int snum);
+int recordInitOutput(int unum, time_t thetime, int snum, int isserver);
 
 int recordReadHeader(fileHeader_t *fhdr);
 int recordReadPkt(Unsgn8 *buf, int blen);
