@@ -1,7 +1,7 @@
 /* 
  * higher level rendering for the CP
  *
- * $Id: render.c 633 2006-09-01 22:02:29Z jon $
+ * $Id: render.c 707 2007-07-04 23:06:09Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -34,6 +34,18 @@ extern dspData_t dData;
 
 #define GLCOLOR4F(glcol) glColor4f(glcol.r, glcol.g, glcol.b, glcol.a) 
 
+/*
+ Cataboligne - 11.20.6
+ ack alert klaxon with <ESC>
+*/
+#include "cqsound.h"
+
+#define ALERT_OFF 0
+#define ALERT_ON 1
+#define ALERT_ACK 2
+
+cqsHandle alertHandle = CQS_INVHANDLE;
+
 /* critical limits */
 
 /*   shields  < 20
@@ -52,12 +64,6 @@ extern dspData_t dData;
 /* we store geometry here that should only need to be recomputed
    when the screen is resized, not every single frame :) */
 
-typedef struct _obj
-{
-  GLfloat x, y;
-  GLfloat w, h;
-
-} obj_t;
 
 static struct {
   GLfloat x, y;                 /* stored x/y/w/h of game window */
@@ -67,72 +73,194 @@ static struct {
 
   GLfloat sb_ih;                /* statbox item height */
 
-  obj_t alertb;                 /* alert border */
+  GLRect_t alertb;              /* alert border */
 
-  obj_t head;
-  obj_t headl;
+  GLRect_t head;
+  GLRect_t headl;
 
-  obj_t warp;
-  obj_t warpl;
+  GLRect_t warp;
+  GLRect_t warpl;
 
-  obj_t sh;
-  obj_t dam;
-  obj_t fuel;
-  obj_t etemp;
-  obj_t wtemp;
-  obj_t alloc;
+  GLRect_t sh;
+  GLRect_t dam;
+  GLRect_t fuel;
+  GLRect_t etemp;
+  GLRect_t wtemp;
+  GLRect_t alloc;
 
-  /* 'stat' box */
-  obj_t kills;
-  obj_t tow;
-  obj_t arm;
-  obj_t cloakdest;
+  /* misc info (viewer) */
+  GLRect_t tow;
+  GLRect_t arm;
+  GLRect_t cloakdest;
 
-  obj_t althud;
-  obj_t rectime;
+  GLRect_t althud;
+  GLRect_t rectime;
 
   /* msg/prompt lines */
-  obj_t msg1;
-  obj_t msg2;
-  obj_t msgmsg;
+  GLRect_t msg1;
+  GLRect_t msg2;
+  GLRect_t msgmsg;
 
-  /* iconhud specific */
-
-  obj_t decal1;                 /* decal 1 location */
-  obj_t d1shg;                  /* shield gauge */
-  obj_t d1shn;                  /* shield value (number) */
-  obj_t d1damg;           
-  obj_t d1damn;           
-  obj_t d1icon;                 /* the icon area */
-  obj_t phasstat;               /* phaser charge status */
-  obj_t d1atarg;                /* ship causing alert */
-  obj_t decal2;                 /* decal 2 location */
-  obj_t d2fuelg;                /* fuel gauge */
-  obj_t d2fueln;                /* fuel value (number) */
-  obj_t d2engtg;
-  obj_t d2engtn;
-  obj_t d2weptg;
-  obj_t d2weptn;
-  obj_t d2allocg;
-  obj_t d2allocn;
-  obj_t d2killb;                /* location of kills box */
-
-  obj_t engfailpulse;           /* wep/eng failure pulses */
-  obj_t wepfailpulse;
-  obj_t fuelcritpulse;
-  obj_t shcritpulse;
-  obj_t hullcritpulse;
-  obj_t shcharge;               /* shield charge status */
+  /* pulse messages (viewer) */
+  GLRect_t engfailpulse;        /* wep/eng failure pulses */
+  GLRect_t wepfailpulse;
+  GLRect_t fuelcritpulse;
+  GLRect_t shcritpulse;
+  GLRect_t hullcritpulse;
   
-  obj_t torppips[MAXTORPS];     /* the torp pips */
+  GLRect_t magfac;                 /* mag factor */
+
+  /* iconhud decals */
+
+  /* decal1 */
+  GLRect_t decal1;              /* decal 1 location */
+  GLRect_t d1shg;               /* shield gauge */
+  GLRect_t d1shcharge;          /* shield charge status */
+  GLRect_t d1shn;               /* shield value (number) */
+  GLRect_t d1damg;              /* damage */
+  GLRect_t d1damn;           
+  GLRect_t d1icon;              /* the ship icon area */
+  GLRect_t d1torps;             /* location of the torp pip area */
+  GLRect_t d1torppips[MAXTORPS]; /* the torp pips */
+  GLRect_t d1phcharge;          /* phaser charge status */
+  GLRect_t d1atarg;             /* ship causing alert */
+
+  /* decal2 */
+  GLRect_t decal2;              /* decal 2 location */
+  GLRect_t d2fuelg;             /* fuel gauge */
+  GLRect_t d2fueln;             /* fuel value (number) */
+  GLRect_t d2engtg;             /* etemp */
+  GLRect_t d2engtn;
+  GLRect_t d2weptg;             /* wtemp */
+  GLRect_t d2weptn;
+  GLRect_t d2allocg;            /* alloc */
+  GLRect_t d2allocn;
+  GLRect_t d2killb;             /* location of kills box */
 
 } o = {};
 
+/* a useful 'mapping' macros for the decals */
+#define MAPAREAX(_decalw, _decalh, _rect) \
+        ( tx + (((_rect)->x / (_decalw) ) * tw) )
+
+#define MAPAREAY(_decalw, _decalh, _rect) \
+        ( decaly + (((_rect)->y / (_decalh)) * th) )
+
+#define MAPAREAW(_decalw, _decalh, _rect) \
+        ( (((_rect)->w / (_decalw)) * tw) )
+
+#define MAPAREAH(_decalw, _decalh, _rect) \
+        ( (((_rect)->h / (_decalh)) * th) )
+
+#define MAPAREA(_decalptr, _taptr, _optr) \
+        {                                 \
+          (_optr)->x = MAPAREAX((_decalptr)->w, (_decalptr)->h, (_taptr)); \
+          (_optr)->y = MAPAREAY((_decalptr)->w, (_decalptr)->h, (_taptr)); \
+          (_optr)->w = MAPAREAW((_decalptr)->w, (_decalptr)->h, (_taptr)); \
+          (_optr)->h = MAPAREAH((_decalptr)->w, (_decalptr)->h, (_taptr)); \
+        }
+
 /* update icon hud geometry if stuff changes (resize).  */
-void updateIconHudGeo(void)
+void updateIconHudGeo(int snum)
 {				/* assumes context is current*/
-  GLfloat tx, ty, th, tw;
+  GLfloat tx, ty, th, tw, decaly;
   int i;
+  static int steam = -1;
+  /* these two rects will just be used to store the texture size (in
+     hw pixels) of each of the 2 decal areas (in w and h).  */
+  static GLRect_t decal1_sz, decal2_sz;
+  /* area pointers, decal1 */
+  static cqiTextureAreaPtr_t d1shg = NULL;  /* d1 sh gauge */
+  static cqiTextureAreaPtr_t d1shchrg = NULL;  /* d1 sh charge gauge */
+  static cqiTextureAreaPtr_t d1shn = NULL;  /* d1 sh number */
+  static cqiTextureAreaPtr_t d1damg = NULL; /* d1 damage gauge */
+  static cqiTextureAreaPtr_t d1damn = NULL; /* d1 damage number */
+  static cqiTextureAreaPtr_t d1torps = NULL; /* d1 torp icon area */
+  static cqiTextureAreaPtr_t d1phaserchrg = NULL; /* d1 phaser charge */
+  static cqiTextureAreaPtr_t d1icon = NULL; /* d1 ship icon area */
+
+  /* area pointers, decal2 */
+  static cqiTextureAreaPtr_t d2fuelg = NULL; /* d2 fuel */
+  static cqiTextureAreaPtr_t d2fueln = NULL; /* d2 number */
+  static cqiTextureAreaPtr_t d2engtg = NULL; /* d2 engine temp */
+  static cqiTextureAreaPtr_t d2engtn = NULL; /* d2 engine number */
+  static cqiTextureAreaPtr_t d2weptg = NULL; /* d2 weapon temp */
+  static cqiTextureAreaPtr_t d2weptn = NULL; /* d2 weapon number */
+  static cqiTextureAreaPtr_t d2allocg = NULL; /* d2 alloc */
+  static cqiTextureAreaPtr_t d2allocn = NULL; /* d2 alloc number */
+  static cqiTextureAreaPtr_t d2killb = NULL; /* d2 kills box */
+  /* default texarea if we couldn't find the right one (1 pixel size) */
+  static cqiTextureAreaRec_t defaultTA = { "NULL", 0.0, 0.0, 1.0, 1.0 };
+  char buffer[CQI_NAMELEN];
+
+  if (Ships[snum].team != steam)
+    {                           /* we switched teams, reload/remap the
+                                   decal texareas */
+      int ndx;
+      steam = Ships[snum].team;
+
+      /* decal 1 */
+      snprintf(buffer, CQI_NAMELEN - 1, "ship%c-ico-decal1", 
+               Teams[steam].name[0]);
+
+      /* get decal1 size */
+      memset((void*)&decal1_sz, 0, sizeof(GLRect_t));
+      if ((ndx = findGLTexture(buffer)) >= 0 )
+        {                       /* this is the decal's texture size
+                                   in pixels */
+          decal1_sz.w = (GLfloat)GLTextures[ndx].w;
+          decal1_sz.h = (GLfloat)GLTextures[ndx].h;
+        } 
+        
+      /* look up the texareas, and clamp to the texture size */
+      d1shg     = cqiFindTexArea(buffer, "shieldg", &defaultTA);
+      CLAMPRECT(decal1_sz.w, decal1_sz.h, d1shg);
+      d1shchrg  = cqiFindTexArea(buffer, "shchargeg", &defaultTA);
+      CLAMPRECT(decal1_sz.w, decal1_sz.h, d1shchrg);
+      d1shn     = cqiFindTexArea(buffer, "shieldn", &defaultTA);
+      CLAMPRECT(decal1_sz.w, decal1_sz.h, d1shn);
+      d1damg    = cqiFindTexArea(buffer, "damageg", &defaultTA);
+      CLAMPRECT(decal1_sz.w, decal1_sz.h, d1damg);
+      d1damn    = cqiFindTexArea(buffer, "damagen", &defaultTA);
+      CLAMPRECT(decal1_sz.w, decal1_sz.h, d1damn);
+      d1icon    = cqiFindTexArea(buffer, "icon", &defaultTA);
+      CLAMPRECT(decal1_sz.w, decal1_sz.h, d1icon);
+      d1torps    = cqiFindTexArea(buffer, "torps", &defaultTA);
+      CLAMPRECT(decal1_sz.w, decal1_sz.h, d1torps);
+      d1phaserchrg = cqiFindTexArea(buffer, "phaserchrg", &defaultTA);
+      CLAMPRECT(decal1_sz.w, decal1_sz.h, d1phaserchrg);
+
+      /* decal 2 */
+      snprintf(buffer, CQI_NAMELEN - 1, "ship%c-ico-decal2", 
+               Teams[steam].name[0]);
+
+      /* get decal2 size */
+      memset((void*)&decal2_sz, 0, sizeof(GLRect_t));
+      if ((ndx = findGLTexture(buffer)) >= 0 )
+        {
+          decal2_sz.w = (GLfloat)GLTextures[ndx].w;
+          decal2_sz.h = (GLfloat)GLTextures[ndx].h;
+        } 
+        
+      d2fuelg   = cqiFindTexArea(buffer, "fuelg", &defaultTA);
+      CLAMPRECT(decal2_sz.w, decal2_sz.h, d2fuelg);
+      d2fueln   = cqiFindTexArea(buffer, "fueln", &defaultTA);
+      CLAMPRECT(decal2_sz.w, decal2_sz.h, d2fueln);
+      d2engtg   = cqiFindTexArea(buffer, "etempg", &defaultTA);
+      CLAMPRECT(decal2_sz.w, decal2_sz.h, d2engtg);
+      d2engtn   = cqiFindTexArea(buffer, "etempn", &defaultTA);
+      CLAMPRECT(decal2_sz.w, decal2_sz.h, d2engtn);
+      d2weptg   = cqiFindTexArea(buffer, "wtempg", &defaultTA);
+      CLAMPRECT(decal2_sz.w, decal2_sz.h, d2weptg);
+      d2weptn   = cqiFindTexArea(buffer, "wtempn", &defaultTA);
+      CLAMPRECT(decal2_sz.w, decal2_sz.h, d2weptn);
+      d2allocg  = cqiFindTexArea(buffer, "allocg", &defaultTA);
+      CLAMPRECT(decal2_sz.w, decal2_sz.h, d2allocg);
+      d2allocn  = cqiFindTexArea(buffer, "allocn", &defaultTA);
+      CLAMPRECT(decal2_sz.w, decal2_sz.h, d2allocn);
+      d2killb   = cqiFindTexArea(buffer, "killsbox", &defaultTA);
+      CLAMPRECT(decal2_sz.w, decal2_sz.h, d2killb);
+    }
 
   o.x = dConf.wX;
   o.y = dConf.wY;
@@ -144,6 +272,7 @@ void updateIconHudGeo(void)
 
   tx = dConf.vX;
   ty = dConf.vY + dConf.vH;
+  /* icon height */
   o.sb_ih = (dConf.wH - (dConf.borderW * 2.0) - ty) / 4.0;
 
   /* alert border */
@@ -173,16 +302,15 @@ void updateIconHudGeo(void)
    * use absolute screen pixel x/y positions in computing these
    * values or scaling/resizing will be broken.
    *
-   * Of course with the decals, these calculations assume a texture
-   * size of 256x256.  The actual texture pixel values were determined
-   * by loading the tex into gimp, positioning the cursor on the area
-   * of interest, and recording the texture pixel start, length, and
+   * The decal texture sizes and the texareas specified in their
+   * texture definitions are used to compute the right x/y/w/h values
+   * for items that are going to be mapped into them (like a fuel
+   * gauge).  The actual texture pixel values were determined by
+   * loading the tex into gimp, positioning the cursor on the area of
+   * interest, and recording the texture pixel start X, Y, width, and
    * height of the area of interest (like the fuel gauge in decal2).
-   * These coordinates are hardcoded in the calulations below.  Yes,
-   * this does suck.  On the plus side, these calculated positions seem
-   * to be consistant among all of the decal textures.  For the future,
-   * CQI should be modified to allow specifying named texcoord sections
-   * in a texture definition, avoiding all of the hardcoding below.
+   * These coordinates are specified as 'texareas' in the decal's
+   * texture definition.  No more hardcoding! :)
    */
 
   /* heading tex and label 
@@ -190,6 +318,11 @@ void updateIconHudGeo(void)
    * the heading icon occupies 2 parts, and the warp 3, then
    * centered within the 6-part area.
    */
+
+  /* we should probably re-do heading/warp as a single texture
+     (decal0?) with texarea's describing the right location to draw
+     things (like decal1 and 2 are handled). */
+
   o.head.x = tx + 2.0;
   o.head.y = ty;
   o.head.w = ((o.xstatw / 6.0) * 2.0);
@@ -200,7 +333,7 @@ void updateIconHudGeo(void)
   o.headl.w = ((o.xstatw / 6.0) * 1.5);
   o.headl.h = (o.head.h / 10.0) * 2.0;
 
-  /* warp tex and label */
+  /* warp tex and label, used for warp backgraound as well */
   o.warp.x = (o.xstatw / 6.0) * 3.0;
   o.warp.y = ty;
   o.warp.w = (o.xstatw / 6.0) * 3.0;
@@ -215,49 +348,46 @@ void updateIconHudGeo(void)
   /* pixel height of decal 1 & 2 */
   th = (dConf.vH / 10.0) * 4.0;
   /* pixel width of decal 1 & 2 */
-  tw = o.xstatw - ((o.xstatw / 10.0) * 2.5);
+  tw = o.xstatw;
 
   /* decal 1 */
-
   o.decal1.x = tx;
   o.decal1.y = ty + ((dConf.vH / 10.0) * 2.0);
   o.decal1.w = tw;
   o.decal1.h = (dConf.vH / 10.0) * 4.0;
 
+  decaly = o.decal1.y;          /* save this for mapping macros */
+
   /* shield gauge */
-  o.d1shg.x = tx + ((96.0 / 256.0) * tw);
-  o.d1shg.y = o.decal1.y + ((18.0 / 256.0) * th);
-  o.d1shg.w = (((175.0 - 96.0) / 256.0) * tw);
-  o.d1shg.h = ((22.0 / 256.0) * th);
+  MAPAREA(&decal1_sz, d1shg, &o.d1shg);
 
   /* shield number (value) */
-  o.d1shn.x = o.decal1.x + o.decal1.w;
-  o.d1shn.y = o.d1shg.y - ((o.d1shg.h * 2.0) * 0.25);
-  o.d1shn.w = o.xstatw - (tx + o.decal1.w);
-  o.d1shn.h = o.d1shg.h * 2.0;
+  MAPAREA(&decal1_sz, d1shn, &o.d1shn);
 
   /* shield charge level (this is just a line) */
-  o.shcharge.x = o.d1shg.x;
-  o.shcharge.y = o.d1shn.y + o.d1shn.h;
-  o.shcharge.w = o.d1shg.w;
-  o.shcharge.h = 2.0;           /* the glLineWidth() in reality */
+  MAPAREA(&decal1_sz, d1shchrg, &o.d1shcharge);
 
   /* damage */
-  o.d1damg.x = tx + ((96.0 / 256.0) * tw);
-  o.d1damg.y = o.decal1.y + ((219.0 / 256.0) * th);
-  o.d1damg.w = (((175.0 - 96.0) / 256.0) * tw);
-  o.d1damg.h = ((21.0 / 256.0) * th);
+  MAPAREA(&decal1_sz, d1damg, &o.d1damg);
 
-  o.d1damn.x = o.decal1.x + o.decal1.w;
-  o.d1damn.y = o.d1damg.y - ((o.d1damg.h * 2.0) * 0.25);
-  o.d1damn.w = o.xstatw - (tx + o.decal1.w);
-  o.d1damn.h = o.d1damg.h * 2.0;
+  MAPAREA(&decal1_sz, d1damn, &o.d1damn);
 
   /* position the ship icon area within decal 1 */
-  o.d1icon.x = tx + ((o.xstatw / 6.0) * 1.0);
-  o.d1icon.y = o.decal1.y + ((43.0 / 256.0) * th) ;
-  o.d1icon.w = ((o.xstatw / 6.0) * 4.0);
-  o.d1icon.h = (o.decal1.y + ((209.0 / 256.0) * th)) - o.d1icon.y;
+  MAPAREA(&decal1_sz, d1icon, &o.d1icon);
+
+  /* torp pips */
+  MAPAREA(&decal1_sz, d1torps, &o.d1torps);
+  for (i=0; i < MAXTORPS; i++)
+    {
+      o.d1torppips[i].x = o.d1torps.x;
+      o.d1torppips[i].y = o.d1torps.y + 
+        (o.d1torps.h / (real)MAXTORPS * (real)i);
+      o.d1torppips[i].w = o.d1torps.w;
+      o.d1torppips[i].h = o.d1torps.h / (real)MAXTORPS;
+    } 
+
+  /* phaser recharge status */
+  MAPAREA(&decal1_sz, d1phaserchrg, &o.d1phcharge);
 
   /* decal 2 */
   o.decal2.x = tx;
@@ -265,51 +395,38 @@ void updateIconHudGeo(void)
   o.decal2.w = tw;
   o.decal2.h = (dConf.vH / 10.0) * 4.0;
 
-  o.d2fuelg.x = tx + ((96.0 / 256.0) * tw);
-  o.d2fuelg.y = o.decal2.y + ((22.0 / 256.0) * th);
-  o.d2fuelg.w = (((175.0 - 96.0) / 256.0) * tw);
-  o.d2fuelg.h = ((17.0 / 256.0) * th);
+  decaly = o.decal2.y;          /* save this for mapping */
 
-  o.d2fueln.x = o.decal2.x + o.decal2.w;
-  o.d2fueln.y = o.d2fuelg.y - ((o.d2fuelg.h * 2.0) * 0.25);
-  o.d2fueln.w = o.xstatw - (tx + o.decal2.w);
-  o.d2fueln.h = o.d2fuelg.h * 2.0;
+  /* fuel */
+  MAPAREA(&decal2_sz, d2fuelg, &o.d2fuelg);
+
+  MAPAREA(&decal2_sz, d2fueln, &o.d2fueln);
   
-  o.d2engtg.x = tx + ((96.0 / 256.0) * tw);
-  o.d2engtg.y = o.decal2.y + ((75.0 / 256.0) * th);
-  o.d2engtg.w = (((175.0 - 96.0) / 256.0) * tw);
-  o.d2engtg.h = ((17.0 / 256.0) * th);
+  /* etemp */
+  MAPAREA(&decal2_sz, d2engtg, &o.d2engtg);
 
-  o.d2engtn.x = o.decal2.x + o.decal2.w;
-  o.d2engtn.y = o.d2engtg.y - ((o.d2engtg.h * 2.0) * 0.25);
-  o.d2engtn.w = o.xstatw - (tx + o.decal2.w);
-  o.d2engtn.h = o.d2engtg.h * 2.0;
+  MAPAREA(&decal2_sz, d2engtn, &o.d2engtn);
 
-  o.d2weptg.x = tx + ((96.0 / 256.0) * tw);
-  o.d2weptg.y = o.decal2.y + ((127.0 / 256.0) * th);
-  o.d2weptg.w = (((175.0 - 96.0) / 256.0) * tw);
-  o.d2weptg.h = ((17.0 / 256.0) * th);
+  /* wtemp */
+  MAPAREA(&decal2_sz, d2weptg, &o.d2weptg);
 
-  o.d2weptn.x = o.decal2.x + o.decal2.w;
-  o.d2weptn.y = o.d2weptg.y - ((o.d2weptg.h * 2.0) * 0.25);
-  o.d2weptn.w = o.xstatw - (tx + o.decal2.w);
-  o.d2weptn.h = o.d2weptg.h * 2.0;
+  MAPAREA(&decal2_sz, d2weptn, &o.d2weptn);
 
-  o.d2allocg.x = tx + ((50.0 / 256.0) * tw);
-  o.d2allocg.y = o.decal2.y + ((184.0 / 256.0) * th);
-  o.d2allocg.w = (((198.0 - 50.0) / 256.0) * tw);
-  o.d2allocg.h = ((17.0 / 256.0) * th);
+  /* allocations */
+  MAPAREA(&decal2_sz, d2allocg, &o.d2allocg);
 
-  o.d2allocn.x = o.decal2.x + o.decal2.w;
-  o.d2allocn.y = o.d2allocg.y - ((o.d2allocg.h * 2.0) * 0.25);
-  o.d2allocn.w = o.xstatw - (tx + o.decal2.w);
-  o.d2allocn.h = o.d2allocg.h * 2.0;
+  MAPAREA(&decal2_sz, d2allocn, &o.d2allocn);
 
-  /* kills, embedded in decal2 */
-  o.d2killb.x = tx + ((164.0 / 256.0) * tw);
-  o.d2killb.y = o.decal2.y + ((217.0 / 256.0) * th);
-  o.d2killb.w = (((249.0 - 164.0) / 256.0) * tw);
-  o.d2killb.h = ((16.0 / 256.0) * th);
+  /* kills box */
+  MAPAREA(&decal2_sz, d2killb, &o.d2killb);
+
+  /* END of the DECALS! */
+
+  /* Cat 'gridscale'.  Now, magfac. */
+  o.magfac.x = dConf.vX + ((dConf.vW / 180.0) * 1.0);
+  o.magfac.y = dConf.vY + (dConf.vH - ((dConf.vH / 20.0) * 1.35));
+  o.magfac.w = (dConf.vW / 12.0) * 1.0;
+  o.magfac.h = (dConf.vH / 38.0) * 1.0;
 
   /*  For tow, armies, and wep/eng pulses, we divide the viewer into 8
    *  horizontal, and 20 vertical segments and confine these items to
@@ -354,23 +471,6 @@ void updateIconHudGeo(void)
   o.engfailpulse.w = ((dConf.vW / 8.0) * 5.0);
   o.engfailpulse.h = (dConf.vH / 20.0) * 2.0;
 
-  /* torp pips, aligned along left side of hud icon area */
-
-  for (i=0; i < MAXTORPS; i++)
-    {
-      o.torppips[i].x = tx + 2.0;
-      o.torppips[i].y = (o.d1icon.y + (o.d1icon.h * 0.15)) +
-        (o.d1icon.h - ((o.d1icon.h * 0.15) * 2.0)) / (real)MAXTORPS * (real)i;
-      o.torppips[i].w = o.d1icon.w * 0.10;
-      o.torppips[i].h = (o.d1icon.h - ((o.d1icon.h * 0.15) * 2.0)) / (real)MAXTORPS;
-    } 
-
-  /* phaser recharge status */
-  o.phasstat.x = tx + 2.0 + o.d1icon.x + o.d1icon.w + (o.d1icon.w * 0.10);
-  o.phasstat.y = o.d1icon.y + (o.d1icon.h * 0.15);
-  o.phasstat.w = o.torppips[0].w / 2.0 /*o.d1icon.w * 0.10*/;
-  o.phasstat.h = o.d1icon.h - ((o.d1icon.h * 0.15) * 2.0);
-  
   /* alert target - bottom of viewer */
   o.d1atarg.x = dConf.vX + ((dConf.vW / 8.0) * 1.5);
   o.d1atarg.y = dConf.vY + (dConf.vH - ((dConf.vH / 20.0) * 1.0));
@@ -423,30 +523,21 @@ void updateIconHudGeo(void)
 void renderScaleVal(GLfloat x, GLfloat y, GLfloat w, GLfloat h, 
                     TexFont *lfont, int val, int col, int boxcol)
 {
-  char buf32[32];
+  static char buf32[32];
+  static int oldval = -1;
 
-  sprintf(buf32, "%3d", val);
+  if (val != oldval)
+    {
+      snprintf(buf32, 32 - 1, "%3d", val);
+      oldval = val;
+    }
 
   /* a scale value (number) */
-  glfRender(x, y, 0.0, w * 0.9, h * 0.8, lfont, buf32, col, NULL,
+  glfRender(x, y, 0.0, w, h, lfont, buf32, col, NULL,
             TRUE, FALSE, TRUE);
-  
-  drawLineBox(x, y, w, h, boxcol, 1.0);
-
   return;
 }
 
-void renderAllocVal(GLfloat x, GLfloat y, GLfloat w, GLfloat h, 
-                    TexFont *lfont, char *val, int col)
-{
-  /* a scale value (number) */
-  glfRender(x, y, 0.0, w * 0.9, h * 0.8, lfont, val, col, NULL,
-            TRUE, FALSE, TRUE);
-  
-  drawLineBox(x, y, w, h, BlueColor, 1.0);
-
-  return;
-}
 
 /* draw overload/critical  messages using a 'pulse' effect
    in the viewer.  Use a slower pulse for 'critical' levels, except
@@ -461,7 +552,8 @@ void renderPulseMsgs(void)
   static animStateRec_t shcrit = {}; 
   static animStateRec_t hullcrit = {}; 
   static int firsttime = TRUE;
-  static const int testlamps = 0;
+  static const int testlamps = 0; /* set to non-zero to see them all
+                                     at once (for testing) */
   scrNode_t *curnode = getTopNode();
   int drawing = FALSE;
   
@@ -641,8 +733,6 @@ void renderPulseMsgs(void)
 /* render the shield's current strength when down */
 void renderShieldCharge(void)
 {
-  GLfloat valxoff = (o.shcharge.w / 10.0) * 3.0;
-  GLfloat scaleend = o.shcharge.x + o.shcharge.w - valxoff - (o.shcharge.w / 10.0);
   real val;
   
   val = CLAMP(0.0, 100.0, Ships[Context.snum].shields);
@@ -653,9 +743,9 @@ void renderShieldCharge(void)
   uiPutColor(dData.sh.color);
   
   /* gauge */
-  drawLine(o.shcharge.x, o.shcharge.y, 
-           scaleend * (GLfloat)((GLfloat)val / 100.0),
-           o.shcharge.h);
+  drawLine(o.d1shcharge.x, o.d1shcharge.y, 
+           o.d1shcharge.w * (GLfloat)((GLfloat)val / 100.0),
+           o.d1shcharge.h);
 
   return;
 }
@@ -664,23 +754,33 @@ void renderShieldCharge(void)
 /* This is Cat's icon hud */
 void renderHud(int dostats)
 {				/* assumes context is current*/
-  char sbuf[128];
-  char fbuf[128];
+  static char sbuf[128];
+  static char ibuf[128];        /* fps, stats, etc */
+  static char fbuf[128];
   int FPS = (int)getFPS();
   cqColor icl;
   real warp = Ships[Context.snum].warp;
   real maxwarp = ShipTypes[Ships[Context.snum].shiptype].warplim;
+  int steam = Ships[Context.snum].team;
+  static int oldteam = -1;
   static int rxtime = 0;
   static int oldrx = 0;
   static int rxdiff = 0;
   int i;
+  static int ack_alert = 0;
+  static struct {
+    real oldFPS;
+    Unsgn32 oldPingAvg;
+    real oldRxdiff;
+  } oldData = {};
+  int magFac;
+  extern int ncpLRMagFactor; /* from nCP */
+  extern int ncpSRMagFactor;
+
 
-  
   if (!GLTextures)
     return;                     /* don't render until we actually can */
 
-  /* draw fps/bps... */
-
   if ((frameTime - rxtime) > 1000)
     {
       rxdiff = pktRXBytes - oldrx;
@@ -688,20 +788,27 @@ void renderHud(int dostats)
       rxtime = frameTime;
     }
 
-  if (FPS > 999)
-    sprintf(fbuf, "FPS: ***");
-  else
-    sprintf(fbuf, "FPS: %03d", FPS);
+  /* update stats data, if needed */
+  if (FPS != oldData.oldFPS || 
+      pingAvgMS != oldData.oldPingAvg || rxdiff != oldData.oldRxdiff)
+    {
+      oldData.oldFPS = FPS;
+      oldData.oldPingAvg = pingAvgMS;
+      oldData.oldRxdiff = rxdiff;
 
-  sprintf(sbuf, "%4dms %3.1fKB/s %s",  
-          pingAvgMS, 
-          ((float)rxdiff / 1000.0),
-          fbuf);
+      snprintf(fbuf, 128 - 1, "FPS: %03d", FPS);
+
+      snprintf(ibuf, 128 - 1, "%4dms %3.1fKB/s %s",  
+               pingAvgMS, 
+               ((float)rxdiff / 1000.0),
+               fbuf);
+    }
 
   if (o.x != dConf.wX || o.y != dConf.wY || o.w != dConf.wW ||
-      o.h != dConf.wH)
+      o.h != dConf.wH || oldteam != steam)
     {
-      updateIconHudGeo();
+      updateIconHudGeo(Context.snum);
+      oldteam = steam;
     }
 
   /* draw alert border */
@@ -719,6 +826,19 @@ void renderHud(int dostats)
             o.headl.h, fontLargeTxf, dData.heading.heading, 
             NoColor, NULL, TRUE, FALSE, TRUE);
 
+  /* warp background */
+  /* kindof sucky to do this here, but since we are drawing a quad
+     sandwiched between two textures... */
+  glEnable(GL_TEXTURE_2D);
+  glEnable(GL_BLEND);
+  glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
+  drawIconHUDDecal(o.warp.x, o.warp.y, o.warp.w, o.warp.h,
+                   HUD_WARP2, 0xffffffff);
+
+  glDisable(GL_BLEND);
+  glDisable(GL_TEXTURE_2D);
+
   /* warp val */
   glfRender(o.warpl.x, o.warpl.y, 0.0, 
             o.warpl.w, o.warpl.h,
@@ -796,9 +916,10 @@ void renderHud(int dostats)
               &dData.alloc, fontLargeTxf, fontFixedTxf, 
               TRUE);
   
-  renderAllocVal(o.d2allocn.x, o.d2allocn.y,
-                 o.d2allocn.w, o.d2allocn.h,
-                 fontFixedTxf, dData.alloc.allocstr, InfoColor);
+  /* alloc value */
+  glfRender(o.d2allocn.x, o.d2allocn.y, 0.0, o.d2allocn.w, o.d2allocn.h, 
+            fontFixedTxf, dData.alloc.allocstr, InfoColor, 
+            NULL, TRUE, FALSE, TRUE);
   
   /* BEGIN "stat" box -
      kills, towing/towed by, x armies, CLOAKED/destruct */
@@ -810,11 +931,12 @@ void renderHud(int dostats)
             o.d2killb.h, fontFixedTxf, dData.kills.kills, InfoColor, NULL,
             TRUE, TRUE, TRUE);
 
+  magFac = (!SMAP(Context.snum)) ? ncpSRMagFactor : ncpLRMagFactor;
   /* towed-towing/armies/destruct/alert - blended text displayed in viewer */
-  if (dData.tow.str[0] || dData.armies.str[0] || 
+  if (magFac || dData.tow.str[0] || dData.armies.str[0] || 
       dData.cloakdest.str[0] == 'D' || dData.aStat.alertStatus[0])
     {
-      /* we want to add an alhpa for these */
+      /* we want to use blending for these */
 
       glBlendFunc(GL_ONE_MINUS_SRC_ALPHA, GL_ONE);
       glEnable(GL_BLEND);
@@ -869,8 +991,67 @@ void renderHud(int dostats)
                     icl | 0x50000000, NULL, TRUE, FALSE, TRUE);
         }
 
+      /* magnification factor */
+      if (magFac)
+        {
+          if (magFac > 0)
+            sprintf(sbuf, "MAG +%1d", magFac);
+          else 
+            sprintf(sbuf, "MAG %1d", magFac);
+          
+          glfRender(o.magfac.x, o.magfac.y, 0.0,
+                    o.magfac.w, o.magfac.h,
+                    fontFixedTxf, sbuf,
+                    SpecialColor | 0x50000000,
+                    NULL, TRUE, FALSE, TRUE);
+        }
+
       glDisable(GL_BLEND);
     }
+
+  /*
+    Cataboligne - sound code to handle red alert klaxon
+    
+    logic - ack_alert inits 0
+    when in red range - if handle is INV meaning sound is off -
+    if ack is OFF play snd, set ack ON
+    if ack is ON - klaxon was turned off with ESC - set ack to ACK
+    when out of red range -
+    set ack to OFF
+    stop sound if playing
+    
+    another idea - play sound whenever near a cloaked ship and
+    (CLOAKED) displays if info gotten
+  */
+  if (dData.aStat.alertStatus[0] == 'R' || dData.aStat.alertStatus[0] == 'A')
+    {                   /* alert condition red - check klaxon state */
+      if (alertHandle == CQS_INVHANDLE) /* not playing now */
+        {
+          if (ack_alert == ALERT_OFF) /* was off */
+            {
+              ack_alert = ALERT_ON;
+              cqsEffectPlayTracked(teamEffects[Ships[Context.snum].team].alert,
+                                   &alertHandle, 0.0, 0.0, 0.0);
+            }
+          else if (ack_alert == ALERT_ON) /* was on - turned off */
+            {
+              ack_alert = ALERT_ACK;  /* been ack'ed in nCP.c with <ESC> */
+            }
+        }
+    }
+  else
+    {
+      /* Cataboligne
+         - idea time out the alert if going beyond the red range?
+         (or just plain stop it here...hmm) */
+      
+      if (alertHandle != CQS_INVHANDLE)
+        {
+          cqsEffectStop(alertHandle, FALSE);
+          alertHandle = CQS_INVHANDLE;
+        }
+      ack_alert = ALERT_OFF; 
+    }
   
   /* GL */
   glBlendFunc(GL_SRC_ALPHA, GL_ONE);
@@ -971,10 +1152,10 @@ void renderHud(int dostats)
               break;
             }
           
-          drawTexQuad(o.torppips[i].x, 
-                      o.torppips[i].y, 
-                      o.torppips[i].w, 
-                      o.torppips[i].h, 
+          drawTexQuad(o.d1torppips[i].x, 
+                      o.d1torppips[i].y, 
+                      o.d1torppips[i].w, 
+                      o.d1torppips[i].h, 
                       0.0);
         }
     }
@@ -1000,7 +1181,7 @@ void renderHud(int dostats)
         {
           glfRender(o.rectime.x, o.rectime.y, 0.0, 
                     o.rectime.w, o.rectime.h,
-                    fontFixedTxf, sbuf, NoColor | CQC_A_DIM, 
+                    fontFixedTxf, ibuf, NoColor | CQC_A_DIM, 
                     NULL, TRUE, TRUE, TRUE);
         }          
     }
@@ -1055,9 +1236,10 @@ void renderHud(int dostats)
       else
         uiPutColor(RedColor);
         
-      drawQuad(o.phasstat.x, o.phasstat.y, o.phasstat.w, 
-               (Ships[Context.snum].pfuse <= 0) ? o.phasstat.h :
-               (o.phasstat.h - (o.phasstat.h / 10.0) * (real)Ships[Context.snum].pfuse), 0.0);
+      drawQuad(o.d1phcharge.x, o.d1phcharge.y, o.d1phcharge.w, 
+               (Ships[Context.snum].pfuse <= 0) ? o.d1phcharge.h :
+               (o.d1phcharge.h - (o.d1phcharge.h / 10.0) * 
+                (real)Ships[Context.snum].pfuse), 0.0);
     }
 
   return;
@@ -1106,18 +1288,18 @@ void renderViewer(int dovbg, int dobomb)
         glBegin(GL_LINES);
 
         /* x */
-        glVertex3f(gx, -VIEWANGLE, TRANZ); /* ul */
-        glVertex3f(gx, VIEWANGLE, TRANZ); /* ur */
+        glVertex3f(gx, -VIEWANGLE, TRANZ);  /* left */
+        glVertex3f(gx, VIEWANGLE, TRANZ);   /* right */
         
-        glVertex3f(-gx, -VIEWANGLE, TRANZ); /* ul */
-        glVertex3f(-gx, VIEWANGLE, TRANZ); /* ur */
+        glVertex3f(-gx, -VIEWANGLE, TRANZ); /* left */
+        glVertex3f(-gx, VIEWANGLE, TRANZ);  /* right */
         
         /* y */
-        glVertex3f(-VIEWANGLE, gy, TRANZ); /* ul */
-        glVertex3f(VIEWANGLE, gy, TRANZ); /* ur */
+        glVertex3f(-VIEWANGLE, gy, TRANZ);  /* top */
+        glVertex3f(VIEWANGLE, gy, TRANZ);   /* bottom */
 
-        glVertex3f(-VIEWANGLE, -gy, TRANZ); /* ul */
-        glVertex3f(VIEWANGLE, -gy, TRANZ); /* ur */
+        glVertex3f(-VIEWANGLE, -gy, TRANZ); /* top */
+        glVertex3f(VIEWANGLE, -gy, TRANZ);  /* bottom */
 
         glEnd();
       }
@@ -1137,43 +1319,14 @@ void renderViewer(int dovbg, int dobomb)
 void renderScale(GLfloat x, GLfloat y, GLfloat w, GLfloat h,
                  int min, int max, int val, int scalecolor) 
 {
-  GLfloat valxoff = (w / 10.0) * 3.0;
-  GLfloat scaleend = x + w - valxoff - (w / 10.0);
-  GLfloat scaleh = h / 2.0;
+  val = CLAMP(min, max, val);
   
-  if (val < min)
-    val = min;
-  if (val > max)
-    val = max;
-
   uiPutColor(scalecolor);
   
   /* gauge */
   drawQuad(x, y, 
-           scaleend * (GLfloat)((GLfloat)val / ((GLfloat)max - (GLfloat)min)),
-           scaleh, 0.0);
-  
-  return;
-}
-
-void renderPhaserScale(GLfloat x, GLfloat y, GLfloat w, GLfloat h,
-                       int min, int max, int val, int scalecolor) 
-{
-  GLfloat valyoff = (h / 10.0) * 3.0;
-  GLfloat scaleend = x + h - valyoff - (h / 10.0);
-  GLfloat scaleh = w / 2.0;
-  
-  if (val < min)
-    val = min;
-  if (val > max)
-    val = max;
-
-  uiPutColor(scalecolor);
-  
-  /* gauge */
-  drawQuad(x, y, 
-           scaleend * (GLfloat)((GLfloat)val / ((GLfloat)max - (GLfloat)min)),
-           scaleh, 0.0);
+           w * (GLfloat)((GLfloat)val / ((GLfloat)max - (GLfloat)min)),
+           h, 0.0);
   
   return;
 }
@@ -1183,9 +1336,6 @@ void renderAlloc(GLfloat x, GLfloat y, GLfloat w, GLfloat h,
                struct _alloc *a,
                TexFont *lfont, TexFont *vfont, int HUD)
 {
-  GLfloat valxoff = (w / 10.0) * 3.0;
-  GLfloat scaleend = x + w - valxoff - (w / 10.0);
-  GLfloat scaleh = h / 2.0;
   int walloc = 0;
   
   /* bg */
@@ -1194,21 +1344,23 @@ void renderAlloc(GLfloat x, GLfloat y, GLfloat w, GLfloat h,
   else
     uiPutColor(RedLevelColor);
 
-  drawQuad(x, y, scaleend, scaleh, 0.0);
+  drawQuad(x, y, w, h, 0.0);
 
   /* fg */
-  walloc = 100 - a->ealloc;
+  
+  if (!a->ealloc)
+    walloc = a->walloc;         /* e overload */
+  else
+    walloc = 100 - a->ealloc;
+
   if (a->walloc > 0)
     uiPutColor(NoColor);
   else
-    {
-      uiPutColor(RedLevelColor);
-      walloc = 100 - a->ealloc;
-    }
+    uiPutColor(RedLevelColor);
 
   drawQuad(x, y, 
-           scaleend * (GLfloat)((GLfloat)walloc / 100.0),
-           scaleh, 0.0);
+           w * (GLfloat)((GLfloat)walloc / 100.0),
+           h, 0.0);
 
   return;
 }
