@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: render.h,v 1.4 2004/10/25 00:15:34 jon Exp $
+ * $Id: render.h 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -8,13 +8,11 @@
 #ifndef _RENDER_H
 #define _RENDER_H
 void renderHud(int dostats);
-void renderViewer(int dovbg);
+void renderViewer(int dovbg, int dobomb);
 void renderScale(GLfloat x, GLfloat y, GLfloat w, GLfloat h,
-                 int min, int max, int val, char *label,
-                 int lcolor, int scalecolor,                  
-                 TexFont *lfont, TexFont *vfont);
+                 int min, int max, int val, int scalecolor);
 void renderAlloc(GLfloat x, GLfloat y, GLfloat w, GLfloat h,
                struct _alloc *a,
-               TexFont *lfont, TexFont *vfont);
+               TexFont *lfont, TexFont *vfont, int HUD);
 
 #endif /* _RENDER_H */
