@@ -4,7 +4,7 @@
  *
  * server specific stuff
  *
- * $Id: server.c,v 1.22 2005/07/11 06:09:35 jon Exp $
+ * $Id: server.c 565 2006-07-24 05:00:20Z jon $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -302,7 +302,14 @@ int sendTorp(int sock, Unsgn8 tsnum, Unsgn8 tnum)
 
 
   /* SP_TORPEVENT */
-  /* we only send these */
+  if (Context.recmode == RECMODE_ON)
+    {
+      if ((storpev = spktTorpEvent(tsnum, tnum, TRUE)))
+        {
+          recordWriteEvent((Unsgn8 *)storpev);
+        }
+    }
+
   if ((storpev = spktTorpEvent(tsnum, tnum, FALSE)))
     {
       if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)storpev) <= 0)
@@ -669,6 +676,7 @@ void procCloak(cpCommand_t *cmd)
   if ( SCLOAKED(snum) )
     {
       SFCLR(snum, SHIP_F_CLOAKED);
+      sendFeedback("Cloaking device disengaged.");
       return;
     }
   if ( Ships[snum].efuse > 0 )
@@ -690,6 +698,7 @@ void procCloak(cpCommand_t *cmd)
     }
 
   SFSET(snum, SHIP_F_CLOAKED);
+  sendFeedback("Cloaking device engaged.");
 
   return;
   
@@ -924,6 +933,8 @@ void procRepair(cpCommand_t *cmd)
       SFSET(snum, SHIP_F_REPAIR);
       Ships[snum].dwarp = 0.0;
     }
+  else
+    sendFeedback("The cloaking device is using all available power.");
 
   return;
 }
@@ -1557,12 +1568,19 @@ void procBomb(cpCommand_t *cmd)
   ototal = -1;			/* force an update the first time */
   oparmies = -1;
   grand( &entertime );		/* get start time */
+  SFSET(snum, SHIP_F_BOMBING);
   while(TRUE)
     {
       if ( ! clbStillAlive( Context.snum ) )
-	return;
+        {
+          SFCLR(snum, SHIP_F_BOMBING);
+          return;
+        }
       if ( isPacketWaiting(sInfo.sock) )
-	break;
+        {
+          SFCLR(snum, SHIP_F_BOMBING);
+          break;
+        }
       
       /* See if it's time to bomb yet. */
       while ((int) fabs ((real)dgrand( (int)entertime, (int *)&now )) >= BOMBARD_GRAND )
@@ -1608,7 +1626,7 @@ void procBomb(cpCommand_t *cmd)
 	      PVUNLOCK(&ConqInfo->lockword);
 	      total = total + 1;
 	    }
-	}
+	} /* while */
       
       if ( Planets[pnum].armies <= MIN_BOMB_ARMIES )
 	{
@@ -1635,10 +1653,13 @@ void procBomb(cpCommand_t *cmd)
       
       c_sleep( ITER_SECONDS );
       
-    }
+    } /* while */
  cbrk22:
   ;
   
+  /* no longer bombing */
+  SFCLR(snum, SHIP_F_BOMBING);
+
   /* Restore shields. */
   if (oldsshup)
     SFSET(snum, SHIP_F_SHUP);
