@@ -4,7 +4,7 @@
  *
  * packet recEvent/pkt generation for the server
  *
- * $Id: serverpkt.c,v 1.9 2004/12/26 08:19:31 jon Exp $
+ * $Id: serverpkt.c 564 2006-07-24 00:52:28Z jon $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -262,7 +262,7 @@ spShipSml_t *spktShipSml(Unsgn8 snum, int rec)
 
   if ((snum == mysnum) || rec)
     {			     /* really only useful for our own ship */
-      sflags |= (SHIP_F_REPAIR | SHIP_F_TALERT);
+      sflags |= (SHIP_F_REPAIR | SHIP_F_TALERT | SHIP_F_BOMBING);
 
       sshipsml.action = (Unsgn8)Ships[snum].action;
       sshipsml.lastblast = htons((Unsgn16)(Ships[snum].lastblast * 100.0));
@@ -310,12 +310,15 @@ spShipSml_t *spktShipSml(Unsgn8 snum, int rec)
 
   if (canscan)
     {				/* if we get all the stats */
-      sflags |= SHIP_F_SHUP;
+      sflags |= SHIP_F_SHUP | SHIP_F_BOMBING | SHIP_F_REPAIR;
 
       sshipsml.shields = (Unsgn8)Ships[snum].shields;
       sshipsml.damage = (Unsgn8)Ships[snum].damage;
       sshipsml.armies = Ships[snum].armies;
 
+      /* so we can do bombing */
+      sshipsml.lock = (Sgn16)htons((Unsgn16)Ships[snum].lock);
+
       /* so we can disp phasers in graphical client ;-) */
       sshipsml.lastphase = htons((Unsgn16)(Ships[snum].lastphase * 100.0));
       sshipsml.pfuse = (Sgn8)Ships[snum].pfuse;
@@ -354,6 +357,10 @@ spShipLoc_t *spktShipLoc(Unsgn8 snum, int rec)
   real x, y;
   int canscan = FALSE;
   real dis;
+  static const Unsgn32 maxtime = 5000;  /* 5 seconds */
+  static Unsgn32 lasttime = 0;
+  Unsgn32 thetime = clbGetMillis();
+  static int forceMyShip = TRUE;
 
   memset((void *)&sshiploc, 0, sizeof(spShipLoc_t));
 
@@ -361,6 +368,17 @@ spShipLoc_t *spktShipLoc(Unsgn8 snum, int rec)
   sshiploc.snum = snum;
   sshiploc.warp = (Sgn8)(Ships[snum].warp * 10.0);
 
+  /* we need to ensure that if we are doing UDP, and we haven't
+     updated a ship in awhile (causing UDP traffic), force an update
+     of your ship even if it isn't neccessary.  This should help with
+     those firewalls that disconnect a UDP connection when there has
+     been no trafic on it for a while. */
+  if (sInfo.doUDP && (snum == mysnum) && ((thetime - lasttime) > maxtime))
+    {
+      lasttime = thetime;
+      forceMyShip = TRUE;
+    }
+
   /* RESTRICT */
   if ((snum == mysnum) || rec)
     {				/* we get everything */
@@ -417,10 +435,16 @@ spShipLoc_t *spktShipLoc(Unsgn8 snum, int rec)
     }
   else
     {
-      if (memcmp((void *)&sshiploc, (void *)&pktShipLoc[snum], 
+      if (forceMyShip || memcmp((void *)&sshiploc, (void *)&pktShipLoc[snum], 
                  sizeof(spShipLoc_t)))
         { 
           pktShipLoc[snum] = sshiploc;
+          /* if we are doing udp, and we are going to send a packet,
+             reset the timer so we won't need a nother force (as we do
+             not need one now :) */
+          if (sInfo.doUDP)
+            lasttime = thetime;
+          forceMyShip = FALSE;
           return &sshiploc;
         }
     }
@@ -797,9 +821,7 @@ spTorpEvent_t *spktTorpEvent(Unsgn8 tsnum, Unsgn8 tnum, int rec)
   storpev.status = (Unsgn8)Ships[tsnum].torps[tnum].status;
 
   /* RESTRICT */
-  /* we can always see friendly torps.  enemy torps can only be seen if 
-     within ACCINFO_DIST of your ship.  torp war stat only applies to
-     your ship. */
+  /* torp war stat only applies to your ship. */
 
   x = Ships[tsnum].torps[tnum].x;
   y = Ships[tsnum].torps[tnum].y;
