@@ -1,7 +1,7 @@
 /* 
  * textures.h
  * 
- * $Id: textures.h 553 2006-07-18 03:04:36Z jon $
+ * $Id: textures.h 699 2007-05-21 02:17:15Z jon $
  *
  * Copyright 1999-2006 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -24,6 +24,10 @@ typedef struct _GLtexture {
   Unsgn32 w, h;                 /* width/height of texture */
 } GLTexture_t;  
 
+typedef struct _GLtexcoord {
+  GLfloat s, t;                 /* texture coordinates or tc offsets */
+} GLTexcoord_t;
+
 #ifdef NOEXTERN_GLTEXTURES
 GLTexture_t *GLTextures = NULL;
 #else
